#!/usr/bin/python2

from __future__ import print_function
import getopt, sys
try:
    import gobject
except ImportError:
    from gi.repository import GObject as gobject

gobject.threads_init()
from dbus import glib
glib.init_threads()

import dbus

def usage():
    print("fake_recall <clientid>")

def main():

    try:
        opts, args = getopt.getopt(sys.argv[1:], "c", [])
        if len(args) < 1:
            usage()
            sys.exit(2)
        clientid = args[0]
        print(clientid)

        bus = dbus.SystemBus()
        cbsim = bus.get_object("org.ganesha.nfsd",
                               "/org/ganesha/nfsd/CBSIM")
        print(cbsim.Introspect())

        # call method
        fake_recall = cbsim.get_dbus_method('fake_recall',
                                       'org.ganesha.nfsd.cbsim')
        print(fake_recall(dbus.UInt64(clientid)))


    except getopt.GetoptError as err:
        print(str(err)) # will print something like "option -a not recognized"
        usage()
        sys.exit(2)

if __name__ == "__main__":
    main()



#!/usr/bin/python2

# You must initialize the gobject/dbus support for threading
# before doing anything.
from __future__ import print_function
try:
    import gobject
except ImportError:
    from gi.repository import GObject as gobject
import sys



gobject.threads_init()
from dbus import glib
glib.init_threads()

# Create a session bus.
import dbus
bus = dbus.SystemBus()

# Create an object that will proxy for a particular remote object.
try:
    admin = bus.get_object("org.ganesha.nfsd",
                       "/org/ganesha/nfsd/ClientMgr")
except: # catch *all* exceptions
    print("Error: Can't talk to ganesha service on d-bus. Looks like Ganesha is down")
    exit(1)



# call method
ganesha_9pOpstats = admin.get_dbus_method('Get9pOpStats',
                                          'org.ganesha.nfsd.clientstats')


# get parameters
if len(sys.argv) != 2:
    print("Usage: %s client_ipaddr" % sys.argv[0])
    exit(1)
client_ipaddr=sys.argv[1]

# for each 9p protocol operation
OpNames=("_9P_TSTATFS", "_9P_TLOPEN", "_9P_TLCREATE", "_9P_TSYMLINK", "_9P_TMKNOD", "_9P_TRENAME", "_9P_TREADLINK", "_9P_TGETATTR", "_9P_TSETATTR", "_9P_TXATTRWALK", "_9P_TXATTRCREATE", "_9P_TREADDIR", "_9P_TFSYNC", "_9P_TLOCK", "_9P_TGETLOCK", "_9P_TLINK", "_9P_TMKDIR", "_9P_TRENAMEAT", "_9P_TUNLINKAT", "_9P_TVERSION", "_9P_TAUTH", "_9P_TATTACH", "_9P_TFLUSH", "_9P_TWALK", "_9P_TOPEN", "_9P_TCREATE", "_9P_TREAD", "_9P_TWRITE", "_9P_TCLUNK", "_9P_TREMOVE", "_9P_TSTAT", "_9P_TWSTAT")

for opname in OpNames:
    opstats=ganesha_9pOpstats(client_ipaddr, opname)
    status=opstats[0]
    errmsg=opstats[1]
    if (not(status)):
        print(errmsg)
        break
    total=opstats[3][0]
    if (total != 0):
        print("%-16s\t%ld" % (opname, total))


sys.exit(0);



#!/usr/bin/python2

# You must initialize the gobject/dbus support for threading
# before doing anything.
from __future__ import print_function
try:
    import gobject
except ImportError:
    from gi.repository import GObject as gobject
import sys

ipaddr=sys.argv[1]
print('event:ip_addr=', ipaddr)

gobject.threads_init()

from dbus import glib
glib.init_threads()

# Create a session bus.
import dbus
bus = dbus.SystemBus()

# Create an object that will proxy for a particular remote object.
try:
    admin = bus.get_object("org.ganesha.nfsd",
                           "/org/ganesha/nfsd/admin")
except dbus.exceptions.DBusException as e:
    sys.exit("Error: Can't talk to ganesha service on d-bus. "
             "Looks like Ganesha is down")

# call method
ganesha_grace = admin.get_dbus_method('grace',
                               'org.ganesha.nfsd.admin')

print("Start grace period.")

try:
    print(ganesha_grace(ipaddr))
except dbus.exceptions.DBusException as e:
    sys.exit("Error: Failed to start grace period")



#!/usr/bin/python2

# You must initialize the gobject/dbus support for threading
# before doing anything.
from __future__ import print_function
try:
    import gobject
except ImportError:
    from gi.repository import GObject as gobject
gobject.threads_init()

from dbus import glib
glib.init_threads()

# Create a session bus.
import dbus
bus = dbus.SystemBus()

# Create an object that will proxy for a particular remote object.
cbsim = bus.get_object("org.ganesha.nfsd",
                       "/org/ganesha/nfsd/CBSIM")
print("introspection data")
introspect = dbus.Interface(
    cbsim,
    dbus.INTROSPECTABLE_IFACE,
    )
print(introspect.Introspect())

# call method
get_client_ids = cbsim.get_dbus_method('get_client_ids',
                                       'org.ganesha.nfsd.cbsim')
print("client ids:")
print(get_client_ids())



#!/usr/bin/python2
#
# This command receives statistics from Ganesha over DBus. The format
# for a command is:
#
# ganesha_stats <subcommand> <args>
#
# ganesha_stats help
#       To get detaled help
#
from __future__ import print_function
import sys
import time
import re
import Ganesha.glib_dbus_stats

def usage():
    message = "Command displays global stats by default.\n"
    message += "To display current status regarding stat counting use \n"
    message += "%s status \n" % (sys.argv[0])
    message += "To display stat counters use \n"
    message += "%s [list_clients | deleg <ip address> | " % (sys.argv[0])
    message += "inode | iov3 [export id] | iov4 [export id] | export |"
    message += " total [export id] | fast | pnfs [export id] |"
    message += " fsal <fsal name> | v3_full | v4_full |"
    message += " auth] \n"
    message += "To reset stat counters use \n"
    message += "%s reset \n" % (sys.argv[0])
    message += "To enable/disable stat counters use \n"
    message += "%s [enable | disable] [all | nfs | fsal | v3_full | " % (sys.argv[0])
    message += "v4_full | auth] \n"
    sys.exit(message)

if len(sys.argv) < 2:
    command = 'global'
else:
    command = sys.argv[1]

# check arguments
commands = ('help', 'list_clients', 'deleg', 'global', 'inode', 'iov3', 'iov4',
        'export', 'total', 'fast', 'pnfs', 'fsal', 'reset', 'enable',
        'disable', 'status', 'v3_full', 'v4_full', 'auth')
if command not in commands:
    print("Option '%s' is not correct." % command)
    usage()
# requires an IP address
elif command in ('deleg'):
    if not len(sys.argv) == 3:
        print("Option '%s' must be followed by an ip address." % command)
        usage()
    command_arg = sys.argv[2]
# optionally accepts an export id
elif command in ('iov3', 'iov4', 'total', 'pnfs'):
    if (len(sys.argv) == 2):
        command_arg = -1
    elif (len(sys.argv) == 3) and sys.argv[2].isdigit():
        command_arg = sys.argv[2]
    else:
        usage()
elif command == "help":
    usage()
# requires fsal name
elif command in ('fsal'):
    if not len(sys.argv) == 3:
        print("Option '%s' must be followed by fsal name." % command)
        usage()
    command_arg = sys.argv[2]
elif command in ('enable', 'disable'):
    if not len(sys.argv) == 3:
        print("Option '%s' must be followed by all/nfs/fsal/v3_full/v4_full/auth" %
            command)
        usage()
    command_arg = sys.argv[2]
    if command_arg not in ('all', 'nfs', 'fsal', 'v3_full', 'v4_full', 'auth'):
        print("Option '%s' must be followed by all/nfs/fsal/v3_full/v4_full/auth" %
            command)
        usage()

# retrieve and print stats
exp_interface = Ganesha.glib_dbus_stats.RetrieveExportStats()
cl_interface = Ganesha.glib_dbus_stats.RetrieveClientStats()
if command == "global":
    print(exp_interface.global_stats())
elif command == "export":
    print(exp_interface.export_stats())
elif command == "inode":
    print(exp_interface.inode_stats())
elif command == "fast":
    print(exp_interface.fast_stats())
elif command == "list_clients":
    print(cl_interface.list_clients())
elif command == "deleg":
    print(cl_interface.deleg_stats(command_arg))
elif command == "iov3":
    print(exp_interface.v3io_stats(command_arg))
elif command == "iov4":
    print(exp_interface.v4io_stats(command_arg))
elif command == "total":
    print(exp_interface.total_stats(command_arg))
elif command == "pnfs":
    print(exp_interface.pnfs_stats(command_arg))
elif command == "reset":
    print(exp_interface.reset_stats())
elif command == "fsal":
    print(exp_interface.fsal_stats(command_arg))
elif command == "v3_full":
    print(exp_interface.v3_full_stats())
elif command == "v4_full":
    print(exp_interface.v4_full_stats())
elif command == "auth":
    print(exp_interface.auth_stats())
elif command == "enable":
    print(exp_interface.enable_stats(command_arg))
elif command == "disable":
    print(exp_interface.disable_stats(command_arg))
elif command == "status":
    print(exp_interface.status_stats())
